# -*- coding: utf-8 -*-
all_plugins = ('grid',)
